diff --git a/location/java/android/location/OnNmeaMessageListener.java b/location/java/android/location/OnNmeaMessageListener.java
index 05647bc5237be..1c02ebd30d585 100644
--- a/location/java/android/location/OnNmeaMessageListener.java
+++ b/location/java/android/location/OnNmeaMessageListener.java
@@ -16,14 +16,17 @@
package android.location;
+import java.util.concurrent.Executor;
+
/**
* Used for receiving NMEA sentences from the GNSS.
* NMEA 0183 is a standard for communicating with marine electronic devices
* and is a common method for receiving data from a GNSS, typically over a serial port.
* See NMEA 0183 for more details.
* You can implement this interface and call {@link LocationManager#addNmeaListener}
* to receive NMEA data from the GNSS engine.
*/
public interface OnNmeaMessageListener {
/**
* Called when an NMEA message is received.
@@ -16,14 +16,17 @@
/**
-* Used for receiving NMEA sentences from the GNSS.
-* NMEA 0183 is a standard for communicating with marine electronic devices
-* and is a common method for receiving data from a GNSS, typically over a serial port.
-* See NMEA 0183 for more details.
-* You can implement this interface and call {@link LocationManager#addNmeaListener}
-* to receive NMEA data from the GNSS engine.
-*/
+ * Used for receiving NMEA sentences from the GNSS.
+ * NMEA 0183 is a standard for communicating with marine electronic devices
+ * and is a common method for receiving data from a GNSS, typically over a serial port.
+ * See NMEA 0183 for more details.
+ * You can implement this interface and call
+ * {@link LocationManager#addNmeaListener(Executor, OnNmeaMessageListener)} to receive NMEA data
+ * from the GNSS engine.
+ */
public interface OnNmeaMessageListener {
/**